#ifndef MAINWINDOW_H
#define MAINWINDOW_H

#include <QMainWindow>
#include <QAudioDeviceInfo>
#include <QAudioInput>
#include <QFile>
#include "lame.h"
typedef lame_global_flags * (*LAMEINIT)     (void);
typedef int (*LAMESETINSAMPLERATE)          (lame_global_flags *, int);
typedef int (*LAMESETNUMCHANNELS)           (lame_global_flags *, int);
typedef int (*LAMESETOUTSAMPLERATE)         (lame_global_flags *, int);
typedef int (*LAMESETBWRITEVBRTAG)          (lame_global_flags *, int);
typedef int (*LAMESETQUALITY)               (lame_global_flags *, int);
typedef int (*LAMESETMODE)                  (lame_global_flags *, MPEG_mode);
typedef int (*LAMESETBRATE)                 (lame_global_flags *, int);
typedef int (*LAMEGETBRATE)                 (const lame_global_flags *);    // this is for testing to se if brate is set in hz or khz
typedef int (*LAMESETCOPYRIGHT)             (lame_global_flags *, int);
typedef int (*LAMESETORIGINAL)              (lame_global_flags *, int);
typedef int (*LAMESETERRORPROTECTION)       (lame_global_flags *, int);
typedef int (*LAMESETVBR)                   (lame_global_flags *, vbr_mode);
typedef int (*LAMEINITPARAMS)               (lame_global_flags *);
typedef const char* (*GETLAMEVERSION)       (void);
typedef const char*  (*GETLAMEURL)          (void);
typedef int (*LAMEENCODEBUFFER)             (
        lame_global_flags*  gfp,           /* global context handle         */
        const short int     buffer_l [],   /* PCM data for left channel     */
        const short int     buffer_r [],   /* PCM data for right channel    */
        const int           nsamples,      /* number of samples per channel */
        unsigned char*      mp3buf,        /* pointer to encoded MP3 stream */
        const int           mp3buf_size ); /* number of valid octets in this
                                              stream                        */
typedef int (*LAMEENCODEFLUSH)              (
        lame_global_flags *  gfp,    /* global context handle                 */
        unsigned char*       mp3buf, /* pointer to encoded MP3 stream         */
        int                  size);  /* number of valid octets in this stream */
typedef int (*LAMECLOSE)                   (lame_global_flags *);


namespace Ui {
    class MainWindow;
}

class MainWindow : public QMainWindow
{
    Q_OBJECT

public:
    explicit MainWindow(QWidget *parent = 0);
    ~MainWindow();

    // pointers to the functions in the libmp3lame library (the ones I use)
    LAMEINIT                lameinit;
    LAMESETINSAMPLERATE     lamesetinsamplerate;
    LAMESETNUMCHANNELS      lamesetnumchannels;
    LAMESETOUTSAMPLERATE    lamesetoutsamplerate;
    LAMESETBWRITEVBRTAG     lamesetbwritevbrtag;
    LAMESETQUALITY          lamesetquality;
    LAMESETMODE             lamesetmode;
    LAMESETBRATE            lamesetbrate;
    LAMEGETBRATE            lamegetbrate;
    LAMESETCOPYRIGHT        lamesetcopyright;
    LAMESETORIGINAL         lamesetoriginal;
    LAMESETERRORPROTECTION  lameseterrorprotection;
    LAMESETVBR              lamesetvbr;
    LAMEINITPARAMS          lameinitparams;
    GETLAMEVERSION          getlameversion;
    GETLAMEURL              getlameurl;
    LAMEENCODEBUFFER        lameencodebuffer;
    LAMEENCODEFLUSH         lameencodeflush;
    LAMECLOSE               lameclose;

    QString getFilename(void);

    // persistant settings data
    QString source;
    int rate;
    int channels;
    bool soundactivated;
    int startlevel;
    int starttime; // in 10 ms ticks
    int stoplevel;
    int stoptime; // in 10 ms ticks
    QString savefolder;
    int MP3Channels; // index to list
    int MP3Frequency; // index to list
    int MP3Bitrate; // index to list
    int MP3Encoding; // index to list
    int MP3Quality; // index to list
    // end persistant settings data

public slots:
    void dosettings(void);
    void record(void);
    void about(void);
    void help(void);

private:
    Ui::MainWindow *ui;

    // functions
    void readSettings(void);
};

#endif // MAINWINDOW_H
